/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.nop;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Properties;

import org.eclipse.emf.ecore.util.EcoreUtil;

import tools.descartes.dql.connector.PerformanceMetricsQueryConnector;
import tools.descartes.dql.models.mapping.domain.AbstractSeriesResult;
import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;
import tools.descartes.dql.models.mapping.domain.ContinuousSeriesResult;
import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.DiscreteSeriesResult;
import tools.descartes.dql.models.mapping.domain.DoF;
import tools.descartes.dql.models.mapping.domain.DomainFactory;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.OnlineResult;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.Result;
import tools.descartes.dql.models.mapping.domain.ResultList;
import tools.descartes.dql.models.mapping.domain.SeriesResultElement;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.domain.StringResult;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;
import tools.descartes.dql.models.mapping.mapping.MappingFactory;

public class PerformanceMetricsQueryConnectorImpl extends AbstractNopQueryConnector
		implements PerformanceMetricsQueryConnector {
	private final DomainFactory domainFactory = DomainFactory.eINSTANCE;
	private Map<String, String> dofMap;

	@Override
	public List<EntityMapping> requestDoFMetrics(final EntityMapping request) {
		fakeProgress();
		final ArrayList<EntityMapping> results = new ArrayList<EntityMapping>();

		Map<String, int[]> dofOptions = getDoFOptions(request);
		int numberOfDofOptions = dofOptions.size();
		recursiveDoFTraverse(dofOptions, numberOfDofOptions, results, 0, request);

		return results;
	}

	private void recursiveDoFTraverse(Map<String, int[]> dofOptions, int numberOfDofOptions, ArrayList<EntityMapping> results,
			int counter, EntityMapping request) {
		if (counter >= numberOfDofOptions) {
			results.add(requestMetrics(request));
		} else {
			Entry<String, int[]> currentOption = getElementNumber(counter, dofOptions);
			for (int i = 0; i < currentOption.getValue().length; i++) {
				getDoFMap().put(currentOption.getKey(), String.valueOf(currentOption.getValue()[i]));
				recursiveDoFTraverse(dofOptions, numberOfDofOptions, results, counter + 1, request);
			}
		}
	}
	
	private Entry<String, int[]> getElementNumber(int number, Map<String, int[]> map) {
		int i = 0;
		for (Entry<String, int[]> entry: map.entrySet()) {
			if (i == number)
				return entry;
			i++;
		}
		return null;
	}

	private Map<String, int[]> getDoFOptions(EntityMapping request) {
		HashMap<String, int[]> dofOptions = new HashMap<String, int[]>();
		for (DoF dof : request.getDoF())
			dofOptions.put(dof.getIdentifier(), parseDoFString((String)dof.getProperties().get("value")));
		return dofOptions;
	}
	
	private static int[] parseDoFString(String s) {
		s = s.replaceAll("(\\[|\\])", "");
		s = s.replaceAll("\\s", "");
		String[] stringPieces = s.split(",");
		int[] ret = new int[stringPieces.length];
		for (int i = 0; i < stringPieces.length; i++) 
			try {
				ret[i] = Integer.parseInt(stringPieces[i]);
			} catch (NumberFormatException e) {
				throw new IllegalStateException("The DoF parameters have to be numbers, but "+ stringPieces[i] 
						+ "is not");
			}
		return ret;
	}

	@Override
	public EntityMapping requestMetrics(final EntityMapping request) {
		fakeProgressIfNotDoF();
		
		final EntityMapping response = EcoreUtil.copy(request);

		validateEntities(request);

		for (final Entity entity : response.getEntities()) {
			for (final Probe probe : entity.getProbes()) {
				for (StatType rt : probe.getStatTypes()) {
					if (probe.getMetricName().startsWith("discreteSeries")) {
						rt.setResult(createDiscreteSeries(probe));
					} else if (probe.getMetricName().startsWith("continuousSeries")) {
						rt.setResult(createContinuousSeriesResult(2, probe.getMetricName()));
					} else if (probe.getMetricName().startsWith("string")) {
						rt.setResult(createStringResult(probe));
					} else if (probe.getMetricName().startsWith("listOfContinuousSeries")) {
						rt.setResult(createContinuousSeriesListResult(probe));
					} else if (probe.getMetricName().startsWith("onlineSeries")) {
						rt.setResult(createOnlineResult(probe));
					} else if (probe.getMetricName().startsWith("differenceSeries")) {
						rt.setResult(createDifferenceSeriesResult(probe));
					} else if(probe.getMetricName().startsWith("pieSeries")){
						rt.setResult(createPieResult(probe));					
					} else if (probe.getMetricName().startsWith("metricWithStat")) {
						System.out.println("No Metric with statTypes yet");
					} else {
						rt.setResult(createDecimalResult(probe));
					}
				}
			}
		}

		return response;
	}

	private void validateEntities(EntityMapping request) {
		ModelStructureQueryConnectorImpl msqc = new ModelStructureQueryConnectorImpl();
		EntityMapping connectorMapping = MappingFactory.eINSTANCE.createEntityMapping();
		connectorMapping = msqc.requestEntities(connectorMapping);

		for (Entity userEntity : request.getEntities()) {
			boolean exists = false;
			for (Entity connectorEntity : connectorMapping.getEntities())
				if (userEntity.getEntityType().equals(connectorEntity.getEntityType())
						&& userEntity.getIdentifier().equals(connectorEntity.getIdentifier()))
					exists = true;
			if (!exists)
				throw new IllegalStateException("There is no Entity from the Type " + userEntity.getEntityType()
						+ " with the identifier " + userEntity.getIdentifier());
		}

	}

	private Result createDecimalResult(Probe probe) {
		final DecimalResult result = domainFactory.createDecimalResult();
		result.setValid(true);

		ConfidenceInterval ci = domainFactory.createConfidenceInterval();
		ci.setAccuracy(BigDecimal.valueOf(0.95));
		ci.setIntervalHalfLength(BigDecimal.valueOf(0.2));
		result.setConfidenceInterval(ci);
		double resultValue = 0;
		for (Entry<String, String> entry: getDoFMap().entrySet())
			resultValue += Integer.valueOf(entry.getValue());
		
		resultValue *= Integer.valueOf(probe.getMetricName().substring(13));
		System.out.println(resultValue);
		result.setValue(BigDecimal.valueOf(resultValue));
		
		return result;
	}

	private Result createOnlineResult(Probe probe) {
		final OnlineResult outerResult = domainFactory.createOnlineResult();
		final AbstractSeriesResult result = domainFactory.createContinuousSeriesResult();
		result.setValid(true);
		result.setXAxisDescription("x");
		result.setYAxisDescription("y");
		outerResult.setResult(result);
		Thread updater = new OnlineSeriesUpdateThread(result, 100, 1000);
		updater.start();
		return outerResult;
	}

	private Result createContinuousSeriesListResult(Probe probe) {
		final ResultList<ContinuousSeriesResult> result = domainFactory
				.createResultList(ContinuousSeriesResult.class);
		result.setValid(true);
		result.getResults().add(createContinuousSeriesResult(3, "Series1"));
		result.getResults().add(createContinuousSeriesResult(10, "Series2"));
		result.getResults().add(createContinuousSeriesResult(7, "Series3"));
		return result;
	}
	
	private Result createDifferenceSeriesResult(Probe probe) {
		final ResultList<ContinuousSeriesResult> result = domainFactory
				.createResultList(ContinuousSeriesResult.class);
		result.setValid(true);
		result.getResults().add(createContinuousSeriesResult(3, "Series1"));
		result.getResults().add(createContinuousSeriesResult(10, "Series2"));
		return result;
	}
	
	

	private Result createStringResult(Probe probe) {
		final StringResult result = domainFactory.createStringResult();
		result.setValid(true);
		result.setValue("This is a String");
		return result;
	}
	
	private Result createPieResult(Probe probe) {
		final ResultList<DecimalResult> result = domainFactory.createResultList(DecimalResult.class);
		result.setValid(true);
		DecimalResult d = domainFactory.createDecimalResult();
		d.setValid(true);
		d.setValue(BigDecimal.valueOf(15));
		
		DecimalResult d1 = domainFactory.createDecimalResult();
		d1.setValid(true);
		d1.setValue(BigDecimal.valueOf(25));
		DecimalResult d2 = domainFactory.createDecimalResult();
		d2.setValid(true);
		d2.setValue(BigDecimal.valueOf(10));
		DecimalResult d3 = domainFactory.createDecimalResult();
		d3.setValid(true);
		d3.setValue(BigDecimal.valueOf(50));
		result.getResults().add(d);
		result.getResults().add(d1);
		result.getResults().add(d2);
		result.getResults().add(d3);
		return result;
	}

	private Result createDiscreteSeries(Probe probe) {
		final DiscreteSeriesResult result = domainFactory.createDiscreteSeriesResult();
		result.setValid(true);
		result.setXAxisDescription("x");
		result.setYAxisDescription("y");
		for (int i = 0; i < 9; i++) {
			SeriesResultElement elem = domainFactory.createSeriesResultElement();
			ConfidenceInterval ci = domainFactory.createConfidenceInterval();
			ci.setAccuracy(BigDecimal.valueOf(0.95));
			ci.setIntervalHalfLength(BigDecimal.valueOf(0.2));
			elem.setConfidenceInterval(ci);
			elem.setX(BigDecimal.valueOf(i));
			elem.setY(BigDecimal.valueOf(Math.cos(i) + 3));
			result.getElements().add(elem);
		}
		return result;
	}

	private ContinuousSeriesResult createContinuousSeriesResult(int j, String name) {
		final ContinuousSeriesResult result = domainFactory.createContinuousSeriesResult();
		result.setValid(true);
		result.setXAxisDescription("x");
		result.setYAxisDescription("y");
		for (int i = 0; i < 9; i++) {
			SeriesResultElement elem = domainFactory.createSeriesResultElement();
			ConfidenceInterval ci = domainFactory.createConfidenceInterval();
			ci.setAccuracy(BigDecimal.valueOf(0.95));
			ci.setIntervalHalfLength(BigDecimal.valueOf(0.2));
			elem.setConfidenceInterval(ci);
			elem.setX(BigDecimal.valueOf(i));
			elem.setY(BigDecimal.valueOf(Math.cos(i) + j));
			result.getElements().add(elem);
		}
		return result;
	}
	
	private Map<String, String> getDoFMap() {
		if (dofMap == null)
			dofMap = ModelStructureQueryConnectorImpl.getDofMap();
		return dofMap;
	}

	@Override
	public String getConstraint() {
		return null;
	}

	@Override
	public String getDoFConstraint() {
		return null;
	}

	@Override
	public String getDoFExplorationStrategy() {
		return null;
	}

	@Override
	public Properties getDoFExplorationStrategyProperties() {
		return null;
	}

	@Override
	public List<String> getSupportedConstraintNames() {
		return null;
	}

	@Override
	public List<String> getSupportedDoFConstraintNames() {
		return null;
	}

	@Override
	public List<String> getSupportedExplorationStrategyNames() {
		return null;
	}

	@Override
	public List<String> getSupportedTimeUnits() {
		return null;
	}

	@Override
	public void setConstraint(final String constraint) {}

	@Override
	public void setDoFConstraint(final String doFConstraint) {}

	@Override
	public void setDoFExplorationStrategy(final String strategy, final Properties properties) {}

	@Override
	public void setObservationPeriod(final Date start, final Date end, final long sampleSize) {}

	@Override
	public void setObservationPeriod(final long amount, final String unit, final long sampleSize) {}

	@Override
	public void setObservationReference(final String type, final String identifier, final long sampleSize) {}

	@Override
	public boolean supportsConstraintRequests() {
		return false;
	}

	@Override
	public boolean supportsDoFRequests() {
		return true;
	}

	@Override
	public boolean supportsMetricRequests() {
		return true;
	}

	@Override
	public boolean supportsObservationPeriods() {
		return false;
	}

	@Override
	public void reset() {}
	
	private void fakeProgressIfNotDoF() {
		StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
		boolean isCalledByDoF = false;
		for (int i = 0; i < stackTrace.length; i++) {
			if (stackTrace[i].getMethodName().equals("requestDoFMetrics")) {
				isCalledByDoF = true;
				break;
			}
		}

		if (!isCalledByDoF) {
			fakeProgress();
		}
	}
	
}
