/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */

package tools.descartes.dql.core.engine.interpreter;

import java.util.LinkedList;
import java.util.List;

import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.xtext.util.Pair;
import org.eclipse.xtext.util.Tuples;

import tools.descartes.dql.core.engine.query.QueryExecutionEngine;
import tools.descartes.dql.core.engine.query.QueryExecutionEngineImpl;
import tools.descartes.dql.lang.descartesQL.AliasClause;
import tools.descartes.dql.lang.descartesQL.ChildrenClause;
import tools.descartes.dql.lang.descartesQL.DescartesQL;
import tools.descartes.dql.lang.descartesQL.DescartesQLFactory;
import tools.descartes.dql.lang.descartesQL.EntityReference;
import tools.descartes.dql.lang.descartesQL.EntityReferenceClause;
import tools.descartes.dql.lang.descartesQL.FindClause;
import tools.descartes.dql.lang.descartesQL.ListEntitiesQuery;
import tools.descartes.dql.lang.descartesQL.ListMetricsQuery;
import tools.descartes.dql.lang.descartesQL.ListQuery;
import tools.descartes.dql.lang.descartesQL.NavigationClause;
import tools.descartes.dql.lang.descartesQL.ParentClause;
import tools.descartes.dql.lang.descartesQL.UsingClause;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class DefaultProvider {

	private DescartesQLFactory dqlFactory = DescartesQLFactory.eINSTANCE;
	private EntityMapping entityAndMetricMapping;
	private UsingClause usingClause;

	public DefaultProvider(UsingClause uc) {
		this.usingClause = uc;
	}

	public String getDefaultStatType(Pair<String, String> id, String metric) {
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (areEqual(e, id))
				for (Probe p : e.getProbes())
					if (p.getMetricName().equals(metric))
						if (p.getStatTypes().isEmpty())
							return "DEFAULT";
						else
							return p.getStatTypes().get(0).getTypeName();
		throw new IllegalStateException("There is no Metric " + id + "." + metric);
	}

	private boolean areEqual(Entity e, Pair<String, String> id) {
		if (e.getIdentifier().equals(id.getSecond())
				&&
				((id.getFirst() == null)
						|| e.getEntityType().equals(id.getFirst())))
				return true;
		return false;
	}

	private EntityMapping getEntityAndMetricMapping() {
		if (entityAndMetricMapping == null)
			initializeEntityAndMetricMapping();
		return entityAndMetricMapping;
	}

	private void initializeEntityAndMetricMapping() {
		EntityMapping entities = lookupEntities();
		EntityMapping entitiesAndMetrics = lookupMetrics(entities);
		this.entityAndMetricMapping = entitiesAndMetrics;
	}

	private EntityMapping lookupMetrics(EntityMapping entities) {
		DescartesQL metricsQuery = dqlFactory.createDescartesQL();
		ListQuery listQuery = dqlFactory.createListQuery();
		metricsQuery.setQuery(listQuery);
		listQuery.setUsingClause(EcoreUtil.copy(usingClause));
		ListMetricsQuery listMetricsQuery = dqlFactory.createListMetricsQuery();
		listQuery.setQueryType(listMetricsQuery);
		listMetricsQuery.setMode("LIST METRICS");
		listMetricsQuery.setEntityReferenceClause(createEntityReferenceClause(entities));

		QueryExecutionEngine qee = new QueryExecutionEngineImpl();
		EntityMapping metrics = qee.execute(metricsQuery).get(0);
		copyRelationships(entities, metrics);
		return metrics;
	}

	private void copyRelationships(EntityMapping mappingWithRelations, EntityMapping mappingWithoutRelations) {
		for (int i = 0; i < mappingWithRelations.getEntities().size(); i++) {
			Entity entityWithRelations = mappingWithRelations.getEntities().get(i);
			Entity entityWithoutRelations = mappingWithoutRelations.getEntities().get(i);
			entityWithoutRelations.setParent(entityWithRelations.getParent());
			entityWithoutRelations.getChildren().addAll(entityWithRelations.getChildren());
		}
	}

	private EntityReferenceClause createEntityReferenceClause(EntityMapping entities) {
		EntityReferenceClause erc = dqlFactory.createEntityReferenceClause();
		for (Entity entity : entities.getEntities()) {
			EntityReference er = dqlFactory.createEntityReference();
			er.setType(entity.getEntityType());
			er.setIdentifier(entity.getIdentifier());
			AliasClause ac = dqlFactory.createAliasClause();
			ac.setAlias(entity.getAlias());
			ac.setMode("AS");
			er.setAlias(ac);
			erc.getEntityReferences().add(er);
		}
		return erc;
	}

	private EntityMapping lookupEntities() {
		DescartesQL entityQuery = dqlFactory.createDescartesQL();
		ListQuery listQuery = dqlFactory.createListQuery();
		entityQuery.setQuery(listQuery);
		listQuery.setUsingClause(EcoreUtil.copy(usingClause));
		ListEntitiesQuery listMetricsQuery = dqlFactory.createListEntitiesQuery();
		listQuery.setQueryType(listMetricsQuery);
		listMetricsQuery.setMode("LIST ENTITIES");

		QueryExecutionEngine qee = new QueryExecutionEngineImpl();
		return qee.execute(entityQuery).get(0);
	}

	public String lookUpEntityType(String identifier) {
		String type = null;
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (e.getIdentifier().equals(identifier))
				if (type == null)
					type = e.getEntityType();
				else
					throw new IllegalStateException("There is more than one Entity with the identifier " + identifier
							+ ", please specify the entityType");

		if (type == null)
			throw new IllegalStateException("There is no Entity with the identifier " + identifier);
		return type;
	}

	public List<Pair<String, String>> processNavigation(NavigationClause navigationClause,
			Pair<String, String> typeAndId) {
		if (navigationClause instanceof ParentClause)
			return processParentClause(typeAndId);
		if (navigationClause instanceof ChildrenClause)
			return processChildrenClause(typeAndId);
		if (navigationClause instanceof FindClause)
			return processFindClause(typeAndId, (FindClause) navigationClause);
		return null;
	}

	private List<Pair<String, String>> processFindClause(Pair<String, String> typeAndId, FindClause navigationClause) {
		List<Pair<String, String>> ret = new LinkedList<Pair<String, String>>();
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (areEqual(e, typeAndId))
				if (!e.getChildren().isEmpty()) {
					for (Entity child : e.getChildren()) {
						if (child.getIdentifier().equals(navigationClause.getChildName()))
							ret.add(Tuples.create(child.getEntityType(), child.getIdentifier()));
						ret.addAll(processFindClause(Tuples.create(child.getEntityType(), child.getIdentifier()),
								navigationClause));
					}
				}
		return ret;
	}

	private List<Pair<String, String>> processChildrenClause(Pair<String, String> typeAndId) {
		List<Pair<String, String>> ret = new LinkedList<Pair<String, String>>();
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (areEqual(e, typeAndId))
				if (e.getChildren().isEmpty())
					throw new IllegalArgumentException("The Entity " + typeAndId.getFirst() + " "
							+ typeAndId.getSecond() + "does not have any children!");
				else {
					for (Entity child : e.getChildren())
						ret.add(Tuples.create(child.getEntityType(), child.getIdentifier()));
				}
		return ret;
	}

	private List<Pair<String, String>> processParentClause(Pair<String, String> typeAndId) {
		List<Pair<String, String>> ret = new LinkedList<Pair<String, String>>();
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (areEqual(e, typeAndId))
				if (e.getParent() == null)
					throw new IllegalArgumentException("The Entity " + typeAndId.getFirst() + " "
							+ typeAndId.getSecond() + "does not have a parent!");
				else
					ret.add(Tuples.create(e.getParent().getEntityType(), e.getParent().getIdentifier()));
		return ret;
	}

	public List<String> getAllEntityTypes() {
		List<String> entityTypes = new LinkedList<String>();
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (!entityTypes.contains(e.getEntityType()))
				entityTypes.add(e.getEntityType());
		return entityTypes;
	}

	public List<Entity> getAllEntities() {
		List<Entity> identifiers = new LinkedList<Entity>();
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (!identifiers.contains(e.getIdentifier()))
				identifiers.add(e);
		return identifiers;
	}

	public List<String> getAllStatTypes(Pair<String, String> id, String metric) {
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (areEqual(e, id))
				for (Probe p : e.getProbes())
					if (p.getMetricName().equals(metric))
						if (p.getStatTypes().isEmpty()) {
							List<String> ret = new LinkedList<String>();
							ret.add("DEFAULT");
							return ret;
						} else {
							List<String> ret = new LinkedList<String>();
							for (StatType st : p.getStatTypes())
								ret.add(st.getTypeName());
							return ret;
						}
		throw new IllegalStateException("There is no Metric " + id + "." + metric);
	}

	public List<String> getAllMetrics(Pair<String, String> id) {
		for (Entity e : getEntityAndMetricMapping().getEntities())
			if (areEqual(e, id)) {
				List<String> metricNames = new LinkedList<String>();
				for (Probe p : e.getProbes())
					metricNames.add(p.getMetricName());
				return metricNames;
			}
		throw new IllegalStateException("There is no Metric " + id);
	}
}
