/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.lang.serializer;

import com.google.inject.Inject;
import java.util.Set;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.xtext.Action;
import org.eclipse.xtext.Parameter;
import org.eclipse.xtext.ParserRule;
import org.eclipse.xtext.serializer.ISerializationContext;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;
import tools.descartes.dql.lang.descartesQL.AbsoluteTimeClause;
import tools.descartes.dql.lang.descartesQL.AggregateMetricClause;
import tools.descartes.dql.lang.descartesQL.AliasClause;
import tools.descartes.dql.lang.descartesQL.ArithmeticClause;
import tools.descartes.dql.lang.descartesQL.ChildrenClause;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertiesClause;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertyClause;
import tools.descartes.dql.lang.descartesQL.ConnectorInstanceReferenceClause;
import tools.descartes.dql.lang.descartesQL.ConnectorTimeUnitClause;
import tools.descartes.dql.lang.descartesQL.ConstraintClause;
import tools.descartes.dql.lang.descartesQL.DescartesQL;
import tools.descartes.dql.lang.descartesQL.DescartesQLPackage;
import tools.descartes.dql.lang.descartesQL.DetectBottlenecksQuery;
import tools.descartes.dql.lang.descartesQL.DetectQuery;
import tools.descartes.dql.lang.descartesQL.DoFClause;
import tools.descartes.dql.lang.descartesQL.DoFReference;
import tools.descartes.dql.lang.descartesQL.DoFVariationClause;
import tools.descartes.dql.lang.descartesQL.EntityReference;
import tools.descartes.dql.lang.descartesQL.EntityReferenceClause;
import tools.descartes.dql.lang.descartesQL.ExplorationStrategyClause;
import tools.descartes.dql.lang.descartesQL.FilterClause;
import tools.descartes.dql.lang.descartesQL.FilterConditionClause;
import tools.descartes.dql.lang.descartesQL.FilterConditionValue;
import tools.descartes.dql.lang.descartesQL.FilterigRule;
import tools.descartes.dql.lang.descartesQL.FilteringClause;
import tools.descartes.dql.lang.descartesQL.FilteringStrategy;
import tools.descartes.dql.lang.descartesQL.FindClause;
import tools.descartes.dql.lang.descartesQL.ForClause;
import tools.descartes.dql.lang.descartesQL.Fuzziness;
import tools.descartes.dql.lang.descartesQL.GetConstraintsQuery;
import tools.descartes.dql.lang.descartesQL.GetExplorationStrategiesQuery;
import tools.descartes.dql.lang.descartesQL.GetQuery;
import tools.descartes.dql.lang.descartesQL.GetTimeUnitsQuery;
import tools.descartes.dql.lang.descartesQL.Goal;
import tools.descartes.dql.lang.descartesQL.IntervalVariationClause;
import tools.descartes.dql.lang.descartesQL.ListDoFQuery;
import tools.descartes.dql.lang.descartesQL.ListEntitiesQuery;
import tools.descartes.dql.lang.descartesQL.ListMetricsQuery;
import tools.descartes.dql.lang.descartesQL.ListQuery;
import tools.descartes.dql.lang.descartesQL.MetricClause;
import tools.descartes.dql.lang.descartesQL.MetricClauses;
import tools.descartes.dql.lang.descartesQL.MetricReference;
import tools.descartes.dql.lang.descartesQL.MetricReferenceClauses;
import tools.descartes.dql.lang.descartesQL.MetricStarClause;
import tools.descartes.dql.lang.descartesQL.ModelFamily;
import tools.descartes.dql.lang.descartesQL.ModelLocation;
import tools.descartes.dql.lang.descartesQL.ModelReferenceClause;
import tools.descartes.dql.lang.descartesQL.MultipleArithmeticClause;
import tools.descartes.dql.lang.descartesQL.ObserveBetweenClause;
import tools.descartes.dql.lang.descartesQL.ObserveClause;
import tools.descartes.dql.lang.descartesQL.ObserveRelativeClause;
import tools.descartes.dql.lang.descartesQL.ParentClause;
import tools.descartes.dql.lang.descartesQL.Penalty;
import tools.descartes.dql.lang.descartesQL.RelativeTimeClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeDurationClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeWithSignClause;
import tools.descartes.dql.lang.descartesQL.SampleClause;
import tools.descartes.dql.lang.descartesQL.SelectQuery;
import tools.descartes.dql.lang.descartesQL.Sla;
import tools.descartes.dql.lang.descartesQL.SlaQuery;
import tools.descartes.dql.lang.descartesQL.Slo;
import tools.descartes.dql.lang.descartesQL.SloQuery;
import tools.descartes.dql.lang.descartesQL.UsingClause;
import tools.descartes.dql.lang.descartesQL.ValueVariationClause;
import tools.descartes.dql.lang.descartesQL.VariableValue;
import tools.descartes.dql.lang.descartesQL.VaryingClause;
import tools.descartes.dql.lang.descartesQL.Violation;
import tools.descartes.dql.lang.descartesQL.WeightedSlo;
import tools.descartes.dql.lang.descartesQL.WhatIfQuery;
import tools.descartes.dql.lang.descartesQL.WhatIfValueVariationClause;
import tools.descartes.dql.lang.descartesQL.WhatIfVariation;
import tools.descartes.dql.lang.descartesQL.WhatIfVariationClause;
import tools.descartes.dql.lang.descartesQL.WithClause;
import tools.descartes.dql.lang.services.DescartesQLGrammarAccess;

@SuppressWarnings("all")
public class DescartesQLSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private DescartesQLGrammarAccess grammarAccess;
	
	@Override
	public void sequence(ISerializationContext context, EObject semanticObject) {
		EPackage epackage = semanticObject.eClass().getEPackage();
		ParserRule rule = context.getParserRule();
		Action action = context.getAssignedAction();
		Set<Parameter> parameters = context.getEnabledBooleanParameters();
		if (epackage == DescartesQLPackage.eINSTANCE)
			switch (semanticObject.eClass().getClassifierID()) {
			case DescartesQLPackage.ABSOLUTE_TIME_CLAUSE:
				sequence_AbsoluteTimeClause(context, (AbsoluteTimeClause) semanticObject); 
				return; 
			case DescartesQLPackage.AGGREGATE_METRIC_CLAUSE:
				sequence_AggregateMetricClause(context, (AggregateMetricClause) semanticObject); 
				return; 
			case DescartesQLPackage.ALIAS_CLAUSE:
				sequence_AliasClause(context, (AliasClause) semanticObject); 
				return; 
			case DescartesQLPackage.ARITHMETIC_CLAUSE:
				sequence_ArithmeticClause(context, (ArithmeticClause) semanticObject); 
				return; 
			case DescartesQLPackage.CHILDREN_CLAUSE:
				sequence_ChildrenClause(context, (ChildrenClause) semanticObject); 
				return; 
			case DescartesQLPackage.CONFIGURATION_PROPERTIES_CLAUSE:
				sequence_ConfigurationPropertiesClause(context, (ConfigurationPropertiesClause) semanticObject); 
				return; 
			case DescartesQLPackage.CONFIGURATION_PROPERTY_CLAUSE:
				sequence_ConfigurationPropertyClause(context, (ConfigurationPropertyClause) semanticObject); 
				return; 
			case DescartesQLPackage.CONNECTOR_INSTANCE_REFERENCE_CLAUSE:
				sequence_ConnectorInstanceReferenceClause(context, (ConnectorInstanceReferenceClause) semanticObject); 
				return; 
			case DescartesQLPackage.CONNECTOR_TIME_UNIT_CLAUSE:
				sequence_ConnectorTimeUnitClause(context, (ConnectorTimeUnitClause) semanticObject); 
				return; 
			case DescartesQLPackage.CONSTRAINT_CLAUSE:
				sequence_ConstraintClause(context, (ConstraintClause) semanticObject); 
				return; 
			case DescartesQLPackage.DESCARTES_QL:
				sequence_DescartesQL(context, (DescartesQL) semanticObject); 
				return; 
			case DescartesQLPackage.DETECT_BOTTLENECKS_QUERY:
				sequence_DetectBottlenecksQuery(context, (DetectBottlenecksQuery) semanticObject); 
				return; 
			case DescartesQLPackage.DETECT_QUERY:
				sequence_DetectQuery(context, (DetectQuery) semanticObject); 
				return; 
			case DescartesQLPackage.DO_FCLAUSE:
				sequence_DoFClause(context, (DoFClause) semanticObject); 
				return; 
			case DescartesQLPackage.DO_FREFERENCE:
				sequence_DoFReference(context, (DoFReference) semanticObject); 
				return; 
			case DescartesQLPackage.DO_FVARIATION_CLAUSE:
				sequence_DoFVariationClause(context, (DoFVariationClause) semanticObject); 
				return; 
			case DescartesQLPackage.ENTITY_REFERENCE:
				sequence_EntityReference(context, (EntityReference) semanticObject); 
				return; 
			case DescartesQLPackage.ENTITY_REFERENCE_CLAUSE:
				sequence_EntityReferenceClause(context, (EntityReferenceClause) semanticObject); 
				return; 
			case DescartesQLPackage.EXPLORATION_STRATEGY_CLAUSE:
				sequence_ExplorationStrategyClause(context, (ExplorationStrategyClause) semanticObject); 
				return; 
			case DescartesQLPackage.FILTER_CLAUSE:
				sequence_FilterClause(context, (FilterClause) semanticObject); 
				return; 
			case DescartesQLPackage.FILTER_CONDITION_CLAUSE:
				sequence_FilterConditionClause(context, (FilterConditionClause) semanticObject); 
				return; 
			case DescartesQLPackage.FILTER_CONDITION_VALUE:
				sequence_FilterConditionValue(context, (FilterConditionValue) semanticObject); 
				return; 
			case DescartesQLPackage.FILTERIG_RULE:
				sequence_FilterigRule(context, (FilterigRule) semanticObject); 
				return; 
			case DescartesQLPackage.FILTERING_CLAUSE:
				sequence_FilteringClause(context, (FilteringClause) semanticObject); 
				return; 
			case DescartesQLPackage.FILTERING_STRATEGY:
				sequence_FilteringStrategy(context, (FilteringStrategy) semanticObject); 
				return; 
			case DescartesQLPackage.FIND_CLAUSE:
				sequence_FindClause(context, (FindClause) semanticObject); 
				return; 
			case DescartesQLPackage.FOR_CLAUSE:
				sequence_ForClause(context, (ForClause) semanticObject); 
				return; 
			case DescartesQLPackage.FUZZINESS:
				sequence_Fuzziness(context, (Fuzziness) semanticObject); 
				return; 
			case DescartesQLPackage.GET_CONSTRAINTS_QUERY:
				sequence_GetConstraintsQuery(context, (GetConstraintsQuery) semanticObject); 
				return; 
			case DescartesQLPackage.GET_EXPLORATION_STRATEGIES_QUERY:
				sequence_GetExplorationStrategiesQuery(context, (GetExplorationStrategiesQuery) semanticObject); 
				return; 
			case DescartesQLPackage.GET_QUERY:
				sequence_GetQuery(context, (GetQuery) semanticObject); 
				return; 
			case DescartesQLPackage.GET_TIME_UNITS_QUERY:
				sequence_GetTimeUnitsQuery(context, (GetTimeUnitsQuery) semanticObject); 
				return; 
			case DescartesQLPackage.GOAL:
				sequence_Goal(context, (Goal) semanticObject); 
				return; 
			case DescartesQLPackage.INTERVAL_VARIATION_CLAUSE:
				sequence_IntervalVariationClause(context, (IntervalVariationClause) semanticObject); 
				return; 
			case DescartesQLPackage.LIST_DO_FQUERY:
				sequence_ListDoFQuery(context, (ListDoFQuery) semanticObject); 
				return; 
			case DescartesQLPackage.LIST_ENTITIES_QUERY:
				sequence_ListEntitiesQuery(context, (ListEntitiesQuery) semanticObject); 
				return; 
			case DescartesQLPackage.LIST_METRICS_QUERY:
				sequence_ListMetricsQuery(context, (ListMetricsQuery) semanticObject); 
				return; 
			case DescartesQLPackage.LIST_QUERY:
				sequence_ListQuery(context, (ListQuery) semanticObject); 
				return; 
			case DescartesQLPackage.METRIC_CLAUSE:
				sequence_MetricClause(context, (MetricClause) semanticObject); 
				return; 
			case DescartesQLPackage.METRIC_CLAUSES:
				sequence_MetricClauses(context, (MetricClauses) semanticObject); 
				return; 
			case DescartesQLPackage.METRIC_REFERENCE:
				sequence_MetricReference(context, (MetricReference) semanticObject); 
				return; 
			case DescartesQLPackage.METRIC_REFERENCE_CLAUSES:
				sequence_MetricReferenceClauses(context, (MetricReferenceClauses) semanticObject); 
				return; 
			case DescartesQLPackage.METRIC_STAR_CLAUSE:
				sequence_MetricStarClause(context, (MetricStarClause) semanticObject); 
				return; 
			case DescartesQLPackage.MODEL_FAMILY:
				sequence_ModelFamily(context, (ModelFamily) semanticObject); 
				return; 
			case DescartesQLPackage.MODEL_LOCATION:
				sequence_ModelLocation(context, (ModelLocation) semanticObject); 
				return; 
			case DescartesQLPackage.MODEL_REFERENCE_CLAUSE:
				sequence_ModelReferenceClause(context, (ModelReferenceClause) semanticObject); 
				return; 
			case DescartesQLPackage.MULTIPLE_ARITHMETIC_CLAUSE:
				sequence_MultipleArithmeticClause(context, (MultipleArithmeticClause) semanticObject); 
				return; 
			case DescartesQLPackage.OBSERVE_BETWEEN_CLAUSE:
				sequence_ObserveBetweenClause(context, (ObserveBetweenClause) semanticObject); 
				return; 
			case DescartesQLPackage.OBSERVE_CLAUSE:
				sequence_ObserveClause(context, (ObserveClause) semanticObject); 
				return; 
			case DescartesQLPackage.OBSERVE_RELATIVE_CLAUSE:
				sequence_ObserveRelativeClause(context, (ObserveRelativeClause) semanticObject); 
				return; 
			case DescartesQLPackage.PARENT_CLAUSE:
				sequence_ParentClause(context, (ParentClause) semanticObject); 
				return; 
			case DescartesQLPackage.PENALTY:
				sequence_Penalty(context, (Penalty) semanticObject); 
				return; 
			case DescartesQLPackage.RELATIVE_TIME_CLAUSE:
				sequence_RelativeTimeClause(context, (RelativeTimeClause) semanticObject); 
				return; 
			case DescartesQLPackage.RELATIVE_TIME_DURATION_CLAUSE:
				sequence_RelativeTimeDurationClause(context, (RelativeTimeDurationClause) semanticObject); 
				return; 
			case DescartesQLPackage.RELATIVE_TIME_WITH_SIGN_CLAUSE:
				sequence_RelativeTimeWithSignClause(context, (RelativeTimeWithSignClause) semanticObject); 
				return; 
			case DescartesQLPackage.SAMPLE_CLAUSE:
				sequence_SampleClause(context, (SampleClause) semanticObject); 
				return; 
			case DescartesQLPackage.SELECT_QUERY:
				sequence_SelectQuery(context, (SelectQuery) semanticObject); 
				return; 
			case DescartesQLPackage.SLA:
				sequence_Sla(context, (Sla) semanticObject); 
				return; 
			case DescartesQLPackage.SLA_QUERY:
				sequence_SlaQuery(context, (SlaQuery) semanticObject); 
				return; 
			case DescartesQLPackage.SLO:
				sequence_Slo(context, (Slo) semanticObject); 
				return; 
			case DescartesQLPackage.SLO_QUERY:
				sequence_SloQuery(context, (SloQuery) semanticObject); 
				return; 
			case DescartesQLPackage.USING_CLAUSE:
				sequence_UsingClause(context, (UsingClause) semanticObject); 
				return; 
			case DescartesQLPackage.VALUE_VARIATION_CLAUSE:
				sequence_ValueVariationClause(context, (ValueVariationClause) semanticObject); 
				return; 
			case DescartesQLPackage.VARIABLE_VALUE:
				sequence_VariableValue(context, (VariableValue) semanticObject); 
				return; 
			case DescartesQLPackage.VARYING_CLAUSE:
				sequence_VaryingClause(context, (VaryingClause) semanticObject); 
				return; 
			case DescartesQLPackage.VIOLATION:
				sequence_Violation(context, (Violation) semanticObject); 
				return; 
			case DescartesQLPackage.WEIGHTED_SLO:
				sequence_WeightedSlo(context, (WeightedSlo) semanticObject); 
				return; 
			case DescartesQLPackage.WHAT_IF_QUERY:
				sequence_WhatIfQuery(context, (WhatIfQuery) semanticObject); 
				return; 
			case DescartesQLPackage.WHAT_IF_VALUE_VARIATION_CLAUSE:
				sequence_WhatIfValueVariationClause(context, (WhatIfValueVariationClause) semanticObject); 
				return; 
			case DescartesQLPackage.WHAT_IF_VARIATION:
				sequence_WhatIfVariation(context, (WhatIfVariation) semanticObject); 
				return; 
			case DescartesQLPackage.WHAT_IF_VARIATION_CLAUSE:
				sequence_WhatIfVariationClause(context, (WhatIfVariationClause) semanticObject); 
				return; 
			case DescartesQLPackage.WITH_CLAUSE:
				sequence_WithClause(context, (WithClause) semanticObject); 
				return; 
			}
		if (errorAcceptor != null)
			errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Contexts:
	 *     BetweenTimeClause returns AbsoluteTimeClause
	 *     TimeClause returns AbsoluteTimeClause
	 *     AbsoluteTimeClause returns AbsoluteTimeClause
	 *
	 * Constraint:
	 *     timeSpec=STRING
	 */
	protected void sequence_AbsoluteTimeClause(ISerializationContext context, AbsoluteTimeClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.ABSOLUTE_TIME_CLAUSE__TIME_SPEC) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.ABSOLUTE_TIME_CLAUSE__TIME_SPEC));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getAbsoluteTimeClauseAccess().getTimeSpecSTRINGTerminalRuleCall_0(), semanticObject.getTimeSpec());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     MetricClauseType returns AggregateMetricClause
	 *     AggregateMetricClause returns AggregateMetricClause
	 *
	 * Constraint:
	 *     (function=StatisticalAggregateType (metrics=MetricStarClause | metrics=MetricClauses) properties=ConfigurationPropertiesClause?)
	 */
	protected void sequence_AggregateMetricClause(ISerializationContext context, AggregateMetricClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     AliasClause returns AliasClause
	 *
	 * Constraint:
	 *     (mode='AS' alias=ID)
	 */
	protected void sequence_AliasClause(ISerializationContext context, AliasClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__MODE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__ALIAS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__ALIAS));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getAliasClauseAccess().getModeASKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getAliasClauseAccess().getAliasIDTerminalRuleCall_1_0(), semanticObject.getAlias());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ArithmeticClause returns ArithmeticClause
	 *
	 * Constraint:
	 *     ((mode='ADD' | mode='SUB' | mode='MULTIPLY') value=VariableValue)
	 */
	protected void sequence_ArithmeticClause(ISerializationContext context, ArithmeticClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     NavigationClause returns ChildrenClause
	 *     ChildrenClause returns ChildrenClause
	 *
	 * Constraint:
	 *     content='children'
	 */
	protected void sequence_ChildrenClause(ISerializationContext context, ChildrenClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CHILDREN_CLAUSE__CONTENT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CHILDREN_CLAUSE__CONTENT));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getChildrenClauseAccess().getContentChildrenKeyword_0(), semanticObject.getContent());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ConfigurationPropertiesClause returns ConfigurationPropertiesClause
	 *
	 * Constraint:
	 *     (mode1='[' properties+=ConfigurationPropertyClause properties+=ConfigurationPropertyClause* mode2=']')
	 */
	protected void sequence_ConfigurationPropertiesClause(ISerializationContext context, ConfigurationPropertiesClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ConfigurationPropertyClause returns ConfigurationPropertyClause
	 *
	 * Constraint:
	 *     (key+=ID key+=ID* value=STRING)
	 */
	protected void sequence_ConfigurationPropertyClause(ISerializationContext context, ConfigurationPropertyClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ObservationClause returns ConnectorInstanceReferenceClause
	 *     ConnectorInstanceReferenceClause returns ConnectorInstanceReferenceClause
	 *
	 * Constraint:
	 *     (type=ID identifier=STRING)
	 */
	protected void sequence_ConnectorInstanceReferenceClause(ISerializationContext context, ConnectorInstanceReferenceClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__TYPE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__IDENTIFIER) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__IDENTIFIER));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getConnectorInstanceReferenceClauseAccess().getTypeIDTerminalRuleCall_0_0(), semanticObject.getType());
		feeder.accept(grammarAccess.getConnectorInstanceReferenceClauseAccess().getIdentifierSTRINGTerminalRuleCall_1_0(), semanticObject.getIdentifier());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ObservationClause returns ConnectorTimeUnitClause
	 *     ConnectorTimeUnitClause returns ConnectorTimeUnitClause
	 *
	 * Constraint:
	 *     (count=INT timeIndicator=ID)
	 */
	protected void sequence_ConnectorTimeUnitClause(ISerializationContext context, ConnectorTimeUnitClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__COUNT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__COUNT));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__TIME_INDICATOR) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__TIME_INDICATOR));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getConnectorTimeUnitClauseAccess().getCountINTTerminalRuleCall_0_0(), semanticObject.getCount());
		feeder.accept(grammarAccess.getConnectorTimeUnitClauseAccess().getTimeIndicatorIDTerminalRuleCall_1_0(), semanticObject.getTimeIndicator());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ConstraintClause returns ConstraintClause
	 *
	 * Constraint:
	 *     type=STRING
	 */
	protected void sequence_ConstraintClause(ISerializationContext context, ConstraintClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONSTRAINT_CLAUSE__TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONSTRAINT_CLAUSE__TYPE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getConstraintClauseAccess().getTypeSTRINGTerminalRuleCall_1_0(), semanticObject.getType());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     DescartesQL returns DescartesQL
	 *
	 * Constraint:
	 *     (
	 *         query=ModelStructureQuery | 
	 *         query=PerformanceMetricsQuery | 
	 *         query=PerformanceIssueQuery | 
	 *         query=ConnectorCapabilityQuery | 
	 *         query=WhatIfQuery | 
	 *         query=Goal
	 *     )
	 */
	protected void sequence_DescartesQL(ISerializationContext context, DescartesQL semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     DetectBottlenecksQuery returns DetectBottlenecksQuery
	 *
	 * Constraint:
	 *     (dofClause=DoFClause usingClause=UsingClause)
	 */
	protected void sequence_DetectBottlenecksQuery(ISerializationContext context, DetectBottlenecksQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__DOF_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__DOF_CLAUSE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__USING_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__USING_CLAUSE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getDetectBottlenecksQueryAccess().getDofClauseDoFClauseParserRuleCall_1_0(), semanticObject.getDofClause());
		feeder.accept(grammarAccess.getDetectBottlenecksQueryAccess().getUsingClauseUsingClauseParserRuleCall_2_0(), semanticObject.getUsingClause());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     PerformanceIssueQuery returns DetectQuery
	 *     DetectQuery returns DetectQuery
	 *
	 * Constraint:
	 *     queryType=DetectBottlenecksQuery
	 */
	protected void sequence_DetectQuery(ISerializationContext context, DetectQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.DETECT_QUERY__QUERY_TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.DETECT_QUERY__QUERY_TYPE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getDetectQueryAccess().getQueryTypeDetectBottlenecksQueryParserRuleCall_1_0(), semanticObject.getQueryType());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     DoFClause returns DoFClause
	 *
	 * Constraint:
	 *     (
	 *         mode='EVALUATE DOF' 
	 *         varyingClause=VaryingClause? 
	 *         explorationStrategy=ExplorationStrategyClause? 
	 *         constraintClause=ConstraintClause? 
	 *         withClause=WithClause?
	 *     )
	 */
	protected void sequence_DoFClause(ISerializationContext context, DoFClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     DoFReference returns DoFReference
	 *
	 * Constraint:
	 *     (doFIdentifier=STRING doFAliasClause=AliasClause? (doFVariationClause=ConfigurationPropertiesClause | doFVariationClause=DoFVariationClause)?)
	 */
	protected void sequence_DoFReference(ISerializationContext context, DoFReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     DoFVariationClause returns DoFVariationClause
	 *
	 * Constraint:
	 *     (mode1='<' (variation=IntervalVariationClause | variation=ValueVariationClause) mode2='>')
	 */
	protected void sequence_DoFVariationClause(ISerializationContext context, DoFVariationClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     EntityReferenceClause returns EntityReferenceClause
	 *
	 * Constraint:
	 *     (entityReferences+=EntityReference entityReferences+=EntityReference*)
	 */
	protected void sequence_EntityReferenceClause(ISerializationContext context, EntityReferenceClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     EntityReference returns EntityReference
	 *
	 * Constraint:
	 *     (type=ID? identifier=STRING alias=AliasClause?)
	 */
	protected void sequence_EntityReference(ISerializationContext context, EntityReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ExplorationStrategyClause returns ExplorationStrategyClause
	 *
	 * Constraint:
	 *     (mode='GUIDED BY' name=STRING parameterClause=ConfigurationPropertiesClause?)
	 */
	protected void sequence_ExplorationStrategyClause(ISerializationContext context, ExplorationStrategyClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     FilterClause returns FilterClause
	 *
	 * Constraint:
	 *     (mode='FILTERED BY' filterConditions+=FilterConditionClause (filterConjunctions+=FilterConjunction filterConditions+=FilterConditionClause)*)
	 */
	protected void sequence_FilterClause(ISerializationContext context, FilterClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     FilterConditionClause returns FilterConditionClause
	 *
	 * Constraint:
	 *     (mode='CONDITION' condition=FilterConditionType value=FilterConditionValue)
	 */
	protected void sequence_FilterConditionClause(ISerializationContext context, FilterConditionClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__MODE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__CONDITION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__CONDITION));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__VALUE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getFilterConditionClauseAccess().getModeCONDITIONKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getFilterConditionClauseAccess().getConditionFilterConditionTypeEnumRuleCall_2_0(), semanticObject.getCondition());
		feeder.accept(grammarAccess.getFilterConditionClauseAccess().getValueFilterConditionValueParserRuleCall_4_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     FilterConditionValue returns FilterConditionValue
	 *
	 * Constraint:
	 *     value=STRING
	 */
	protected void sequence_FilterConditionValue(ISerializationContext context, FilterConditionValue semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_VALUE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_VALUE__VALUE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getFilterConditionValueAccess().getValueSTRINGTerminalRuleCall_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     FilterigRule returns FilterigRule
	 *
	 * Constraint:
	 *     (filteringValue=VariableValue modifier='%'?)
	 */
	protected void sequence_FilterigRule(ISerializationContext context, FilterigRule semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     FilteringClause returns FilteringClause
	 *
	 * Constraint:
	 *     (filterungRule=FilterigRule | filteringStrategy=FilteringStrategy)
	 */
	protected void sequence_FilteringClause(ISerializationContext context, FilteringClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     FilteringStrategy returns FilteringStrategy
	 *
	 * Constraint:
	 *     filteringStrategy=STRING
	 */
	protected void sequence_FilteringStrategy(ISerializationContext context, FilteringStrategy semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTERING_STRATEGY__FILTERING_STRATEGY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTERING_STRATEGY__FILTERING_STRATEGY));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getFilteringStrategyAccess().getFilteringStrategySTRINGTerminalRuleCall_0(), semanticObject.getFilteringStrategy());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     NavigationClause returns FindClause
	 *     FindClause returns FindClause
	 *
	 * Constraint:
	 *     (start='find(' childName=STRING end=')')
	 */
	protected void sequence_FindClause(ISerializationContext context, FindClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FIND_CLAUSE__START) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FIND_CLAUSE__START));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FIND_CLAUSE__CHILD_NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FIND_CLAUSE__CHILD_NAME));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FIND_CLAUSE__END) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FIND_CLAUSE__END));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getFindClauseAccess().getStartFindKeyword_0_0(), semanticObject.getStart());
		feeder.accept(grammarAccess.getFindClauseAccess().getChildNameSTRINGTerminalRuleCall_1_0(), semanticObject.getChildName());
		feeder.accept(grammarAccess.getFindClauseAccess().getEndRightParenthesisKeyword_2_0(), semanticObject.getEnd());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ForClause returns ForClause
	 *
	 * Constraint:
	 *     (mode='FOR' entityReferenceClause=EntityReferenceClause)
	 */
	protected void sequence_ForClause(ISerializationContext context, ForClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__MODE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__ENTITY_REFERENCE_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__ENTITY_REFERENCE_CLAUSE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getForClauseAccess().getModeFORKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getForClauseAccess().getEntityReferenceClauseEntityReferenceClauseParserRuleCall_1_0(), semanticObject.getEntityReferenceClause());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     Fuzziness returns Fuzziness
	 *
	 * Constraint:
	 *     (type='FUZZINESS' deviation=VariableValue)
	 */
	protected void sequence_Fuzziness(ISerializationContext context, Fuzziness semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FUZZINESS__TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FUZZINESS__TYPE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FUZZINESS__DEVIATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FUZZINESS__DEVIATION));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getFuzzinessAccess().getTypeFUZZINESSKeyword_0_0(), semanticObject.getType());
		feeder.accept(grammarAccess.getFuzzinessAccess().getDeviationVariableValueParserRuleCall_1_0(), semanticObject.getDeviation());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     GetConstraintsQuery returns GetConstraintsQuery
	 *
	 * Constraint:
	 *     mode='CONSTRAINTS'
	 */
	protected void sequence_GetConstraintsQuery(ISerializationContext context, GetConstraintsQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.GET_CONSTRAINTS_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.GET_CONSTRAINTS_QUERY__MODE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getGetConstraintsQueryAccess().getModeCONSTRAINTSKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     GetExplorationStrategiesQuery returns GetExplorationStrategiesQuery
	 *
	 * Constraint:
	 *     mode='EXPLORATION STRATEGIES'
	 */
	protected void sequence_GetExplorationStrategiesQuery(ISerializationContext context, GetExplorationStrategiesQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.GET_EXPLORATION_STRATEGIES_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.GET_EXPLORATION_STRATEGIES_QUERY__MODE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getGetExplorationStrategiesQueryAccess().getModeEXPLORATIONSTRATEGIESKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ConnectorCapabilityQuery returns GetQuery
	 *     GetQuery returns GetQuery
	 *
	 * Constraint:
	 *     ((queryTape=GetExplorationStrategiesQuery | queryTape=GetTimeUnitsQuery | queryTape=GetConstraintsQuery) usingClause=UsingClause)
	 */
	protected void sequence_GetQuery(ISerializationContext context, GetQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     GetTimeUnitsQuery returns GetTimeUnitsQuery
	 *
	 * Constraint:
	 *     mode='TIME UNITS'
	 */
	protected void sequence_GetTimeUnitsQuery(ISerializationContext context, GetTimeUnitsQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.GET_TIME_UNITS_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.GET_TIME_UNITS_QUERY__MODE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getGetTimeUnitsQueryAccess().getModeTIMEUNITSKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     Goal returns Goal
	 *
	 * Constraint:
	 *     ((queryType='ENSURE' | queryType='MONITOR') slaQuery=SlaQuery sloQuery=SloQuery forClause=ForClause? usingClause=UsingClause)
	 */
	protected void sequence_Goal(ISerializationContext context, Goal semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     IntervalVariationClause returns IntervalVariationClause
	 *
	 * Constraint:
	 *     (start=INT end=INT step=INT)
	 */
	protected void sequence_IntervalVariationClause(ISerializationContext context, IntervalVariationClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__START) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__START));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__END) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__END));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__STEP) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__STEP));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getIntervalVariationClauseAccess().getStartINTTerminalRuleCall_0_0(), semanticObject.getStart());
		feeder.accept(grammarAccess.getIntervalVariationClauseAccess().getEndINTTerminalRuleCall_2_0(), semanticObject.getEnd());
		feeder.accept(grammarAccess.getIntervalVariationClauseAccess().getStepINTTerminalRuleCall_4_0(), semanticObject.getStep());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ListDoFQuery returns ListDoFQuery
	 *
	 * Constraint:
	 *     (mode='DOF' withClause=WithClause?)
	 */
	protected void sequence_ListDoFQuery(ISerializationContext context, ListDoFQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ListEntitiesQuery returns ListEntitiesQuery
	 *
	 * Constraint:
	 *     mode='ENTITIES'
	 */
	protected void sequence_ListEntitiesQuery(ISerializationContext context, ListEntitiesQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_ENTITIES_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_ENTITIES_QUERY__MODE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getListEntitiesQueryAccess().getModeENTITIESKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ListMetricsQuery returns ListMetricsQuery
	 *
	 * Constraint:
	 *     (mode='METRICS' entityReferenceClause=EntityReferenceClause)
	 */
	protected void sequence_ListMetricsQuery(ISerializationContext context, ListMetricsQuery semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__MODE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__ENTITY_REFERENCE_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__ENTITY_REFERENCE_CLAUSE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getListMetricsQueryAccess().getModeMETRICSKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getListMetricsQueryAccess().getEntityReferenceClauseEntityReferenceClauseParserRuleCall_2_0(), semanticObject.getEntityReferenceClause());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ModelStructureQuery returns ListQuery
	 *     ListQuery returns ListQuery
	 *
	 * Constraint:
	 *     ((queryType=ListEntitiesQuery | queryType=ListMetricsQuery | queryType=ListDoFQuery) filterClause=FilterClause? usingClause=UsingClause)
	 */
	protected void sequence_ListQuery(ISerializationContext context, ListQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     MetricClauseType returns MetricClause
	 *     MetricClause returns MetricClause
	 *
	 * Constraint:
	 *     metricReference=MetricReference
	 */
	protected void sequence_MetricClause(ISerializationContext context, MetricClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.METRIC_CLAUSE__METRIC_REFERENCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.METRIC_CLAUSE__METRIC_REFERENCE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getMetricClauseAccess().getMetricReferenceMetricReferenceParserRuleCall_0(), semanticObject.getMetricReference());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     MetricClauses returns MetricClauses
	 *
	 * Constraint:
	 *     (metrics+=MetricClause metrics+=MetricClause*)
	 */
	protected void sequence_MetricClauses(ISerializationContext context, MetricClauses semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     MetricReferenceClauses returns MetricReferenceClauses
	 *
	 * Constraint:
	 *     (metricClauseTypes+=MetricClauseType metricClauseTypes+=MetricClauseType*)
	 */
	protected void sequence_MetricReferenceClauses(ISerializationContext context, MetricReferenceClauses semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     MetricReference returns MetricReference
	 *
	 * Constraint:
	 *     (entityReference=ID (seperatorn='.' navigationClause=NavigationClause)? separator='.' metricReference=ID (separatorv='.' statTypeReference=ID)?)
	 */
	protected void sequence_MetricReference(ISerializationContext context, MetricReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     MetricStarClause returns MetricStarClause
	 *
	 * Constraint:
	 *     metricName=ID
	 */
	protected void sequence_MetricStarClause(ISerializationContext context, MetricStarClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.METRIC_STAR_CLAUSE__METRIC_NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.METRIC_STAR_CLAUSE__METRIC_NAME));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getMetricStarClauseAccess().getMetricNameIDTerminalRuleCall_1_0(), semanticObject.getMetricName());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ModelFamily returns ModelFamily
	 *
	 * Constraint:
	 *     family=ID
	 */
	protected void sequence_ModelFamily(ISerializationContext context, ModelFamily semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_FAMILY__FAMILY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_FAMILY__FAMILY));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getModelFamilyAccess().getFamilyIDTerminalRuleCall_0(), semanticObject.getFamily());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ModelLocation returns ModelLocation
	 *
	 * Constraint:
	 *     location=STRING
	 */
	protected void sequence_ModelLocation(ISerializationContext context, ModelLocation semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_LOCATION__LOCATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_LOCATION__LOCATION));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getModelLocationAccess().getLocationSTRINGTerminalRuleCall_0(), semanticObject.getLocation());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ModelReferenceClause returns ModelReferenceClause
	 *
	 * Constraint:
	 *     (family=ModelFamily model=ModelLocation)
	 */
	protected void sequence_ModelReferenceClause(ISerializationContext context, ModelReferenceClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__FAMILY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__FAMILY));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__MODEL) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__MODEL));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getModelReferenceClauseAccess().getFamilyModelFamilyParserRuleCall_0_0(), semanticObject.getFamily());
		feeder.accept(grammarAccess.getModelReferenceClauseAccess().getModelModelLocationParserRuleCall_2_0(), semanticObject.getModel());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     MultipleArithmeticClause returns MultipleArithmeticClause
	 *
	 * Constraint:
	 *     (multiClause+=ArithmeticClause multiClause+=ArithmeticClause*)
	 */
	protected void sequence_MultipleArithmeticClause(ISerializationContext context, MultipleArithmeticClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ObservationClause returns ObserveBetweenClause
	 *     ObserveBetweenClause returns ObserveBetweenClause
	 *
	 * Constraint:
	 *     (
	 *         mode1='BETWEEN' 
	 *         (startingTime=AbsoluteTimeClause | startingTime=RelativeTimeWithSignClause) 
	 *         mode2='AND' 
	 *         (endingTime=AbsoluteTimeClause | endingTime=RelativeTimeWithSignClause)
	 *     )
	 */
	protected void sequence_ObserveBetweenClause(ISerializationContext context, ObserveBetweenClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ObserveClause returns ObserveClause
	 *
	 * Constraint:
	 *     (mode='OBSERVE' observation=ObservationClause sampleClause=SampleClause?)
	 */
	protected void sequence_ObserveClause(ISerializationContext context, ObserveClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     ObservationClause returns ObserveRelativeClause
	 *     ObserveRelativeClause returns ObserveRelativeClause
	 *
	 * Constraint:
	 *     (direction=ObserveRelativeDirectionType (timeTarget=AbsoluteTimeClause | timeTarget=RelativeTimeClause))
	 */
	protected void sequence_ObserveRelativeClause(ISerializationContext context, ObserveRelativeClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     NavigationClause returns ParentClause
	 *     ParentClause returns ParentClause
	 *
	 * Constraint:
	 *     content='parent'
	 */
	protected void sequence_ParentClause(ISerializationContext context, ParentClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.PARENT_CLAUSE__CONTENT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.PARENT_CLAUSE__CONTENT));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getParentClauseAccess().getContentParentKeyword_0(), semanticObject.getContent());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     Penalty returns Penalty
	 *
	 * Constraint:
	 *     (type='PENALTY' value=DOUBLE currency=Currency violation=Violation?)
	 */
	protected void sequence_Penalty(ISerializationContext context, Penalty semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     TimeClause returns RelativeTimeClause
	 *     RelativeTimeClause returns RelativeTimeClause
	 *
	 * Constraint:
	 *     (durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*)
	 */
	protected void sequence_RelativeTimeClause(ISerializationContext context, RelativeTimeClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     RelativeTimeDurationClause returns RelativeTimeDurationClause
	 *
	 * Constraint:
	 *     (duration=INT timeModifier=TimeModifierType)
	 */
	protected void sequence_RelativeTimeDurationClause(ISerializationContext context, RelativeTimeDurationClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__DURATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__DURATION));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__TIME_MODIFIER) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__TIME_MODIFIER));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getRelativeTimeDurationClauseAccess().getDurationINTTerminalRuleCall_0_0(), semanticObject.getDuration());
		feeder.accept(grammarAccess.getRelativeTimeDurationClauseAccess().getTimeModifierTimeModifierTypeEnumRuleCall_1_0(), semanticObject.getTimeModifier());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     RelativeTimeWithSignClause returns RelativeTimeWithSignClause
	 *     BetweenTimeClause returns RelativeTimeWithSignClause
	 *
	 * Constraint:
	 *     (sign=RelativeTimeSignType timeClause=RelativeTimeClause)
	 */
	protected void sequence_RelativeTimeWithSignClause(ISerializationContext context, RelativeTimeWithSignClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__SIGN) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__SIGN));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__TIME_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__TIME_CLAUSE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getRelativeTimeWithSignClauseAccess().getSignRelativeTimeSignTypeEnumRuleCall_0_0(), semanticObject.getSign());
		feeder.accept(grammarAccess.getRelativeTimeWithSignClauseAccess().getTimeClauseRelativeTimeClauseParserRuleCall_1_0(), semanticObject.getTimeClause());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     SampleClause returns SampleClause
	 *
	 * Constraint:
	 *     (mode='SAMPLED BY' durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*)
	 */
	protected void sequence_SampleClause(ISerializationContext context, SampleClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     PerformanceMetricsQuery returns SelectQuery
	 *     SelectQuery returns SelectQuery
	 *
	 * Constraint:
	 *     (
	 *         metricReferenceClauses=MetricReferenceClauses 
	 *         constraintClause=ConstraintClause? 
	 *         dofClause=DoFClause? 
	 *         forClause=ForClause 
	 *         usingClause=UsingClause 
	 *         observeClause=ObserveClause?
	 *     )
	 */
	protected void sequence_SelectQuery(ISerializationContext context, SelectQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     SlaQuery returns SlaQuery
	 *
	 * Constraint:
	 *     (type='AGREEMENTS' slas+=Sla sloa+=Sla*)
	 */
	protected void sequence_SlaQuery(ISerializationContext context, SlaQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     Sla returns Sla
	 *
	 * Constraint:
	 *     (name=ID weightedSlo+=WeightedSlo weightedSlo+=WeightedSlo*)
	 */
	protected void sequence_Sla(ISerializationContext context, Sla semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     SloQuery returns SloQuery
	 *
	 * Constraint:
	 *     (type='GOALS' slos+=Slo slos+=Slo*)
	 */
	protected void sequence_SloQuery(ISerializationContext context, SloQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     Slo returns Slo
	 *
	 * Constraint:
	 *     (
	 *         name=ID 
	 *         metricClauseType=MetricClauseType 
	 *         comparator=Comparator 
	 *         value=VariableValue 
	 *         fuz=Fuzziness? 
	 *         pen=Penalty?
	 *     )
	 */
	protected void sequence_Slo(ISerializationContext context, Slo semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     UsingClause returns UsingClause
	 *
	 * Constraint:
	 *     (mode='USING' modelReference=ModelReferenceClause)
	 */
	protected void sequence_UsingClause(ISerializationContext context, UsingClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODEL_REFERENCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODEL_REFERENCE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getUsingClauseAccess().getModeUSINGKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getUsingClauseAccess().getModelReferenceModelReferenceClauseParserRuleCall_1_0(), semanticObject.getModelReference());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     ValueVariationClause returns ValueVariationClause
	 *
	 * Constraint:
	 *     (value+=INT value+=INT*)
	 */
	protected void sequence_ValueVariationClause(ISerializationContext context, ValueVariationClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     VariableValue returns VariableValue
	 *
	 * Constraint:
	 *     (intValue=INT | doubleValue=DOUBLE)
	 */
	protected void sequence_VariableValue(ISerializationContext context, VariableValue semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     VaryingClause returns VaryingClause
	 *
	 * Constraint:
	 *     (mode='VARYING' dofReferences+=DoFReference dofReferences+=DoFReference*)
	 */
	protected void sequence_VaryingClause(ISerializationContext context, VaryingClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     Violation returns Violation
	 *
	 * Constraint:
	 *     amount=INT
	 */
	protected void sequence_Violation(ISerializationContext context, Violation semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.VIOLATION__AMOUNT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.VIOLATION__AMOUNT));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getViolationAccess().getAmountINTTerminalRuleCall_1_0(), semanticObject.getAmount());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     WeightedSlo returns WeightedSlo
	 *
	 * Constraint:
	 *     (slo=[Slo|ID] weight=INT?)
	 */
	protected void sequence_WeightedSlo(ISerializationContext context, WeightedSlo semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     WhatIfQuery returns WhatIfQuery
	 *
	 * Constraint:
	 *     (
	 *         whatIfVariation=WhatIfVariation 
	 *         (metricReferenceClauses=MetricReferenceClauses forClause=ForClause)? 
	 *         filteringClause=FilteringClause? 
	 *         deltaClause=DeltaClause? 
	 *         usingClause=UsingClause
	 *     )
	 */
	protected void sequence_WhatIfQuery(ISerializationContext context, WhatIfQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     WhatIfValueVariationClause returns WhatIfValueVariationClause
	 *
	 * Constraint:
	 *     (dofVariationClause=DoFVariationClause | multipleArithmethicClause=MultipleArithmeticClause)
	 */
	protected void sequence_WhatIfValueVariationClause(ISerializationContext context, WhatIfValueVariationClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     WhatIfVariationClause returns WhatIfVariationClause
	 *
	 * Constraint:
	 *     (variationPoint=STRING values=WhatIfValueVariationClause)
	 */
	protected void sequence_WhatIfVariationClause(ISerializationContext context, WhatIfVariationClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.WHAT_IF_VARIATION_CLAUSE__VARIATION_POINT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.WHAT_IF_VARIATION_CLAUSE__VARIATION_POINT));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.WHAT_IF_VARIATION_CLAUSE__VALUES) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.WHAT_IF_VARIATION_CLAUSE__VALUES));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getWhatIfVariationClauseAccess().getVariationPointSTRINGTerminalRuleCall_0_0(), semanticObject.getVariationPoint());
		feeder.accept(grammarAccess.getWhatIfVariationClauseAccess().getValuesWhatIfValueVariationClauseParserRuleCall_1_0(), semanticObject.getValues());
		feeder.finish();
	}
	
	
	/**
	 * Contexts:
	 *     WhatIfVariation returns WhatIfVariation
	 *
	 * Constraint:
	 *     (whatIfVariationClause+=WhatIfVariationClause whatIfVariationClause+=WhatIfVariationClause*)
	 */
	protected void sequence_WhatIfVariation(ISerializationContext context, WhatIfVariation semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Contexts:
	 *     WithClause returns WithClause
	 *
	 * Constraint:
	 *     (mode='WITH' modelReference=ModelReferenceClause)
	 */
	protected void sequence_WithClause(ISerializationContext context, WithClause semanticObject) {
		if (errorAcceptor != null) {
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODE));
			if (transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODEL_REFERENCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODEL_REFERENCE));
		}
		SequenceFeeder feeder = createSequencerFeeder(context, semanticObject);
		feeder.accept(grammarAccess.getWithClauseAccess().getModeWITHKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getWithClauseAccess().getModelReferenceModelReferenceClauseParserRuleCall_1_0(), semanticObject.getModelReference());
		feeder.finish();
	}
	
	
}
